<template>
    <div class="app-container">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
            <el-form-item label="体检号" prop="tjNumber">
                <el-input v-model="queryParams.tjNumber" placeholder="请输入体检号" clearable @keyup.enter.native="handleQuery" ref="inputName" @blur="handleQuery" />
            </el-form-item>
            <el-form-item label="用户名" prop="userName">
                <el-input v-model="queryParams.userName" placeholder="请输入用户名" clearable @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="${comment}" prop="hzDoctorName">
                <el-input v-model="queryParams.hzDoctorName" placeholder="请输入${comment}" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
                <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
                    v-hasPermi="['hosp:replylog:add']">新增
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
                    v-hasPermi="['hosp:replylog:edit']">修改
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
                    v-hasPermi="['hosp:replylog:remove']">删除
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
                    v-hasPermi="['hosp:replylog:export']">导出
                </el-button>
            </el-col>
            <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>

        <el-table v-loading="loading" :data="replylogList" @selection-change="handleSelectionChange">
            <el-table-column type="selection" width="55" align="center" />
            <el-table-column label="会诊id" align="center" prop="id" />
            <el-table-column label="会诊订单id" align="center" prop="orderId" />
            <el-table-column label="体检号" align="center" prop="tjNumber" />
            <el-table-column label="用户id" align="center" prop="userId" />
            <el-table-column label="用户名" align="center" prop="userName" />
            <el-table-column label="会诊类型0全院会诊1科室会诊" align="center" prop="hzType" />
            <el-table-column label="回复医生" align="center" prop="replyDoctorId" />
            <el-table-column label="回复医生名" align="center" prop="replyDoctorName" />
            <el-table-column label="回复部门" align="center" prop="replyDeptId" />
            <el-table-column label="回复部门名" align="center" prop="replyDeptName" />
            <el-table-column label="回复内容" align="center" prop="replyContent" />
            <el-table-column label="" align="center" prop="status" />
            <el-table-column label="" align="center" prop="remark" />
            <el-table-column label="会诊申请id" align="center" prop="hzId" />
            <el-table-column label="${comment}" align="center" prop="hzDoctorId" />
            <el-table-column label="${comment}" align="center" prop="hzDoctorName" />
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
                <template slot-scope="scope">
                    <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
                        v-hasPermi="['hosp:replylog:edit']">修改
                    </el-button>
                    <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
                        v-hasPermi="['hosp:replylog:remove']">删除
                    </el-button>
                </template>
            </el-table-column>
        </el-table>

        <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
            @pagination="getList" />

        <!-- 添加或修改会诊回复记录对话框 -->
        <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
            <el-form ref="form" :model="form" :rules="rules" label-width="80px">
                <el-form-item label="会诊订单id" prop="orderId">
                    <el-input v-model="form.orderId" placeholder="请输入会诊订单id" />
                </el-form-item>
                <el-form-item label="体检号" prop="tjNumber">
                    <el-input v-model="form.tjNumber" placeholder="请输入体检号" />
                </el-form-item>
                <el-form-item label="用户id" prop="userId">
                    <el-input v-model="form.userId" placeholder="请输入用户id" />
                </el-form-item>
                <el-form-item label="用户名" prop="userName">
                    <el-input v-model="form.userName" placeholder="请输入用户名" />
                </el-form-item>
                <el-form-item label="回复医生" prop="replyDoctorId">
                    <el-input v-model="form.replyDoctorId" placeholder="请输入回复医生" />
                </el-form-item>
                <el-form-item label="回复医生名" prop="replyDoctorName">
                    <el-input v-model="form.replyDoctorName" placeholder="请输入回复医生名" />
                </el-form-item>
                <el-form-item label="回复部门" prop="replyDeptId">
                    <el-input v-model="form.replyDeptId" placeholder="请输入回复部门" />
                </el-form-item>
                <el-form-item label="回复部门名" prop="replyDeptName">
                    <el-input v-model="form.replyDeptName" placeholder="请输入回复部门名" />
                </el-form-item>
                <el-form-item label="回复内容">
                    <editor v-model="form.replyContent" :min-height="192" />
                </el-form-item>
                <el-form-item label="" prop="remark">
                    <el-input v-model="form.remark" placeholder="请输入" />
                </el-form-item>
                <el-form-item label="会诊申请id" prop="hzId">
                    <el-input v-model="form.hzId" placeholder="请输入会诊申请id" />
                </el-form-item>
                <el-form-item label="${comment}" prop="hzDoctorId">
                    <el-input v-model="form.hzDoctorId" placeholder="请输入${comment}" />
                </el-form-item>
                <el-form-item label="${comment}" prop="hzDoctorName">
                    <el-input v-model="form.hzDoctorName" placeholder="请输入${comment}" />
                </el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import {
    listReplylog,
    getReplylog,
    delReplylog,
    addReplylog,
    updateReplylog
} from "@/api/hosp/replylog";

export default {
    name: "Replylog",
    data() {
        return {
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            // 会诊回复记录表格数据
            replylogList: [],
            // 弹出层标题
            title: "",
            // 是否显示弹出层
            open: false,
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                tjNumber: null,
                userName: null,
                hzType: null,
                hzDoctorName: null
            },
            // 表单参数
            form: {},
            // 表单校验
            rules: {
            }
        };
    },
    created() {
        this.getList();
    },
    mounted() {
    this.$nextTick(() => {
      this.$refs.inputName.focus();
    });
  },
    methods: {
        /** 查询会诊回复记录列表 */
        getList() {
            this.loading = true;
            listReplylog(this.queryParams).then(response => {
                this.replylogList = response.rows;
                this.total = response.total;
                this.loading = false;
            });
        },
        // 取消按钮
        cancel() {
            this.open = false;
            this.reset();
        },
        // 表单重置
        reset() {
            this.form = {
                id: null,
                orderId: null,
                tjNumber: null,
                userId: null,
                userName: null,
                hzType: null,
                replyDoctorId: null,
                replyDoctorName: null,
                replyDeptId: null,
                replyDeptName: null,
                replyContent: null,
                status: "0",
                remark: null,
                createTime: null,
                updateTime: null,
                createBy: null,
                updateBy: null,
                deleted: null,
                hzId: null,
                hzDoctorId: null,
                hzDoctorName: null
            };
            this.resetForm("form");
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1;
            this.getList();
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.resetForm("queryForm");
            this.handleQuery();
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.ids = selection.map(item => item.id)
            this.single = selection.length !== 1
            this.multiple = !selection.length
        },
        /** 新增按钮操作 */
        handleAdd() {
            this.reset();
            this.open = true;
            this.title = "添加会诊回复记录";
        },
        /** 修改按钮操作 */
        handleUpdate(row) {
            this.reset();
            const id = row.id || this.ids
            getReplylog(id).then(response => {
                this.form = response.data;
                this.open = true;
                this.title = "修改会诊回复记录";
            });
        },
        /** 提交按钮 */
        //         submitForm() {
        //             this.$]]
        //             #refs["form"].validate(valid => {
        //                 if (valid) {
        //                     #foreach($column in $columns)
        //                     #if($column.htmlType == "checkbox")
        //                     this.form.$column.javaField = this.form.$
        //                     {
        //                         column.javaField
        //                     }
        //                 .
        //                     join(",");
        //                     #end
        //                     #end
        //                     #if($table.sub)
        //                     this.form.$
        //                     {
        //                         subclassName
        //                     }
        //                     List = this.$
        //                     {
        //                         subclassName
        //                     }
        //                     List;
        //                     #end
        //                     if (this.form.${
        //                         pkColumn.javaField
        //                     }
        //                 !=
        //                     null
        //                 )
        //                     {
        //                         update$
        //                         {
        //                             BusinessName
        //                         }
        //                         (this.form).then(response => {
        //                             this.#[[$modal]]
        //                             #.msgSuccess("修改成功");
        //                             this.open = false;
        //                             this.getList();
        //                         });
        //                     }
        //                 else
        //                     {
        //                         add$
        //                         {
        //                             BusinessName
        //                         }
        //                         (this.form).then(response => {
        //                             this.#[[$modal]]
        //                             #.msgSuccess("新增成功");
        //                             this.open = false;
        //                             this.getList();
        //                         });
        //                     }
        //                 }
        //             });
        //         },
        //         /** 删除按钮操作 */
        //         handleDelete(row) {
        //             const ${pkColumn.javaField}s = row.$
        //             {
        //                 pkColumn.javaField
        //             }
        //         ||
        //             this.ids;
        //             this.#[[$modal]]
        //             #.confirm('是否确认删除${functionName}编号为"' + ${pkColumn.javaField}s + '"的数据项？').then(function () {
        //                 return del$
        //                 {
        //                     BusinessName
        //                 }
        //                 (${pkColumn.javaField}s);
        //             }).then(() => {
        //                 this.getList();
        //                 this.#[[$modal]]
        //                 #.msgSuccess("删除成功");
        //             }).catch(() => {
        //             });
        //         },
        // #if($table.sub)
        // /** ${subTable.functionName}序号 */
        // row$
        // {
        //     subClassName
        // }
        // Index({row, rowIndex})
        // {
        //     row.index = rowIndex + 1;
        // }
        // ,
        // /** ${subTable.functionName}添加按钮操作 */
        // handleAdd$
        // {
        //     subClassName
        // }
        // ()
        // {
        //     let obj = {};
        //     #foreach($column in $subTable.columns)
        //     #if($column.pk || $column.javaField == ${subTableFkclassName})
        //     #elseif($column.list && "" != $javaField)
        //     obj.$column.javaField = "";
        //     #end
        //     #end
        //     this.$
        //     {
        //         subclassName
        //     }
        //     List.push(obj);
        // }
        // ,
        // /** ${subTable.functionName}删除按钮操作 */
        // handleDelete$
        // {
        //     subClassName
        // }
        // ()
        // {
        //     if (this.checked${
        //         subClassName
        //     }
        // .
        //     length == 0
        // )
        //     {
        //         this.#[[$modal]]
        //         #.msgError("请先选择要删除的${subTable.functionName}数据");
        //     }
        // else
        //     {
        //         const ${subclassName}List = this.$
        //         {
        //             subclassName
        //         }
        //         List;
        //         const checked$
        //         {
        //             subClassName
        //         }
        //         = this.checked$
        //         {
        //             subClassName
        //         }
        //         ;
        //         this.$
        //         {
        //             subclassName
        //         }
        //         List = ${subclassName}List.filter(function (item) {
        //             return checked$
        //             {
        //                 subClassName
        //             }
        //         .
        //             indexOf(item.index) == -1
        //         });
        //     }
        // }
        // ,
        // /** 复选框选中数据 */
        // handle$
        // {
        //     subClassName
        // }
        // SelectionChange(selection)
        // {
        //     this.checked$
        //     {
        //         subClassName
        //     }
        //     = selection.map(item => item.index)
        // }
        // ,
        // #end
        // /** 导出按钮操作 */
        // handleExport()
        // {
        //     this.download('${moduleName}/${businessName}/export', {
        //         ...this.queryParams
        //     }, `${businessName}_#[[${new Date().getTime()}.xlsx`)
        // }
    }
}
    ;
</script>
